.. _diagrams:

``dhcpcanon`` diagrams
=========================

Finite State Machine diagram
--------------------------------

.. image:: ./images/dhcpcapfsm.*

Classes diagram
---------------

.. image:: ./images/classes_dhcpcanon.*

Package diagram
--------------------

.. image:: ./images/packages_dhcpcanon.*
